package zendesk.messaging.android

import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.SupervisorJob
import zendesk.android.messaging.Messaging
import zendesk.android.messaging.MessagingFactory
import zendesk.messaging.android.internal.DefaultMessaging
import zendesk.messaging.android.internal.ProcessLifecycleObserver
import zendesk.messaging.android.internal.UnreadMessageCounter

/**
 * This factory is the starting point to begin using [Messaging]. It can be used to create instances of [Messaging],
 * which is the main entry point of the SDK.
 */
public class DefaultMessagingFactory : MessagingFactory {
    override fun create(params: MessagingFactory.CreateParams): Messaging = DefaultMessaging(
        credentials = params.credentials,
        messagingSettings = params.messagingSettings,
        conversationKit = params.conversationKit,
        dispatchEvent = params.dispatchEvent,
        processLifecycleObserver = ProcessLifecycleObserver.newInstance(),
        coroutineScope = CoroutineScope(context = Dispatchers.Default + SupervisorJob()),
        unreadMessageCounter = UnreadMessageCounter(),
    )
}
