package zendesk.messaging.android

/**
 * A discriminated union that encapsulates a successful outcome with a value of type [T]
 * or a failure with a message and an arbitrary [Throwable] cause.
 */
@Deprecated(message = "Please use Zendesk SDK")
public sealed class MessagingResult<out T> {

    /**
     * A successful outcome with a value of type [T].
     *
     * @param T the type of the [value]
     * @property value the value
     */
    public data class Success<T>(val value: T) : MessagingResult<T>()

    /**
     * A failure outcome with a message and an optional arbitrary [Throwable] cause.
     *
     * @property cause an optional arbitrary [Throwable] exception, null by default
     */
    public data class Failure(
        val cause: MessagingError? = null
    ) : MessagingResult<Nothing>() {

        /**
         * The [cause] message if available, or empty.
         */
        val message: String = cause?.message ?: ""
    }
}
